@@ -29,7 +29,7 @@ our @EXPORT = qw(
 our @ISA = qw(Exporter);
 
 # Set the package version. 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 # Use inline C code.
 use Inline 'C';
@@ -162,7 +162,9 @@ sub read_file {
 sub login_users {
     # Assign the function argument to the local variable.  
     my $user = `users`;
+    # Write logged-in user to array.
     my @user_arr = split ' ', $user;
+    # Return the array.
     return @user_arr;
 }
 
@@ -170,22 +172,36 @@ sub login_users {
 # Subroutine login_shells                                                      #
 #                                                                              #
 # Description:                                                                 #
-# Write allowed login shells to array.                                         #
+# Read the content of the file /etc/shells and store the content in a string   #
+# variable. Then the content is splited up into lines. In a loop the lines are #
+# used where a valid login shell is given. Then the path is removed from the   #
+# line with the login shell. The login shell is added to an array. In a last   #
+# step douple entries are removed from the array.                              #
 #------------------------------------------------------------------------------# 
 sub login_shells {
-    # Assign the function argument to the local variable.  
-    my @login_arr;
-    my $content = read_file("/etc/shells");
+    # Declare the login shell array.
+    my @login_array;
+    # Set the file for reading.
+    my $file = "/etc/shells";
+    # Read the content from the file.
+    my $content = read_file($file);
+    # Loop over the lines of the file content.
     foreach (split '\n', $content) {
+        # Trim the new line.
         my $line = trim($_);
+        # Use only a line with a valid login shell. 
         if ($line =~ /^\/.*\/(.*)$/) {
+            # Remove the path from the line with the login shell.
             my ($shell) = $line =~ /^\/.*\/(.*)$/;
-            push(@login_arr, $shell);
+            # Add the login shell to the array.
+            push(@login_array, $shell);
         };
     };
-    my %hash = map { $_, 1 } @login_arr;
-    @login_arr = keys %hash;
-    return @login_arr;
+    # Remove double entries from the array.
+    my %hash = map {$_, 1} @login_array;
+    @login_array = keys %hash;
+    # Return the array with the login shells.
+    return @login_array;
 };
 
 #------------------------------------------------------------------------------# 
@@ -571,12 +587,24 @@ Terminal emulators tested so far with the package:
 
 =item * MATE-Terminal
 
+=item * QTerminal
+
 =item * ROXTerm
 
+=item * Sakura
+
+=item * Terminator
+
 =item * Terminology
 
+=item * Termit
+
+=item * Tilda
+
 =item * Tilix
 
+=item * UXTerm
+
 =item * Xfce4-Terminal-Emulator
 
 =item * xiterm+thai
